==> ark-4.10.5.tar.xz: ark-4.10.5/plugins/karchiveplugin/kerfuffle_karchive.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_karchive
X-KDE-PluginInfo-Author=Henrique Pinto
X-KDE-PluginInfo-Email=henrique.pinto@kdemail.net
X-KDE-PluginInfo-Name=kerfuffle_karchive
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=117
X-KDE-Kerfuffle-APIRevision=1
Name=kerfuffle_karchive
Name[ar]=kerfuffle_karchive
Name[ast]=kerfuffle_karchive
Name[bg]=kerfuffle_karchive
Name[bs]=kerfuffle_karchive
Name[ca]=kerfuffle_karchive
Name[ca@valencia]=kerfuffle_karchive
Name[cs]=kerfuffle_karchive
Name[da]=kerfuffle_karchive
Name[de]=kerfuffle_karchive
Name[el]=kerfuffle_karchive
Name[en_GB]=kerfuffle_karchive
Name[es]=kerfuffle_karchive
Name[et]=kerfuffle_karchive
Name[eu]=kerfuffle_karchive
Name[fi]=kerfuffle_karchive
Name[fr]=kerfuffle_karchive
Name[ga]=kerfuffle_karchive
Name[gl]=kerfuffle_karchive
Name[he]=kerfuffle_karchive
Name[hne]=करफुफल_केआर्काइव
Name[hr]=kerfuffle_karchive
Name[hu]=kerfuffle_karchive
Name[ia]=kerfuffle_karchive
Name[id]=kerfuffle_karchive
Name[it]=kerfuffle_karchive
Name[ja]=kerfuffle_karchive
Name[kk]=kerfuffle_karchive
Name[km]=kerfuffle_karchive
Name[ko]=kerfuffle_karchive
Name[lt]=kerfuffle_karchive
Name[lv]=kerfuffle_karchive
Name[mr]=कर्फफल_के-संग्रह
Name[nb]=kerfuffle_karchive
Name[nds]=kerfuffle_karchive
Name[nl]=kerfuffle_karchive
Name[nn]=kerfuffle_karchive
Name[pa]=kerfuffle_karchive
Name[pl]=kerfuffle_karchive
Name[pt]=kerfuffle_karchive
Name[pt_BR]=kerfuffle_karchive
Name[ro]=kerfuffle_karchive
Name[ru]=kerfuffle_karchive
Name[sk]=kerfuffle_karchive
Name[sl]=kerfuffle_karchive
Name[sq]=kerfuffle_karchive
Name[sr]=kerfuffle_karchive
Name[sr@ijekavian]=kerfuffle_karchive
Name[sr@ijekavianlatin]=kerfuffle_karchive
Name[sr@latin]=kerfuffle_karchive
Name[sv]=Kerfuffle Karchive
Name[ta]=கெர்ஃபஃபில் கேஆர்கைவ்
Name[th]=kerfuffle_karchive
Name[tr]=kerfuffle_karchive
Name[uk]=kerfuffle_karchive
Name[wa]=kerfuffle_karchive
Name[x-test]=xxkerfuffle_karchivexx
Name[zh_CN]=kerfuffle_karchive
Name[zh_TW]=kerfuffle_karchive
Comment=KArchive plugin for Kerfuffle
Comment[ar]=KArchive ملحق لـ Kerfuffle
Comment[ast]=Aplicación KArchive pa Kerfuffle
Comment[bg]=Приставка KArchive за Kerfuffle
Comment[bs]=Priključak KArchive za Kerfafl
Comment[ca]=Connector del KArchive pel Kerfuffle
Comment[ca@valencia]=Connector del KArchive pel Kerfuffle
Comment[cs]=KArchive modul pro Kerfuffle
Comment[da]=KArchive-plugin til Kerfuffle
Comment[de]=KArchive-Modul für Kerfuffle
Comment[el]=πρόσθετο KArchive για τη Kerfuffle
Comment[en_GB]=KArchive plugin for Kerfuffle
Comment[es]=Complemento KArchive para Kerfuffle
Comment[et]=Kerfuffle'i KArchive plugin
Comment[eu]=Kerfuffle-rentzako KArchive plugina
Comment[fi]=KArchive-pakkaustuki
Comment[fr]=Module externe « KArchive » pour Kerfuffle
Comment[ga]=Breiseán KArchive le haghaidh Kerfuffle
Comment[gl]=Extensión de KArchive para Kerfuffle
Comment[he]=תוסף KArchive  עבור Kerfuffle
Comment[hne]=करफुफल बर केआर्काइव प्लगइन
Comment[hr]=Priključak KArchive za Kerfuffle
Comment[hu]=KArchive Kerfuffle-modul
Comment[ia]=Plugin de Karchive per Kerfuffle
Comment[id]=Pengaya KArchive untuk Kerfuffle
Comment[it]=Estensione KArchive per Kerfuffle
Comment[ja]=Kerfuffle のための KArchive プラグイン
Comment[kk]=Kerfuffle-ге арналған KArchive плагині
Comment[km]=កម្មវិធី​របស់ KArchive សម្រាប់ Kerfuffle
Comment[ko]=Kerfuffle을 위한 KArchive 플러그인
Comment[lt]=KArchive Kerfuffle priedas
Comment[lv]=Kerfuffle KArchive spraudnis
Comment[mr]=कर्फफल करिता के-संग्रह प्लगइन
Comment[nb]=KArchive programtillegg for Kerfuffle
Comment[nds]=KArchive-Moduul för Kerfuffle
Comment[nl]=KArchive-plug-in voor Kerfuffle
Comment[nn]=KArchive-programtillegg til Kerfuffle
Comment[pl]=Wtyczka KArchive dla Kerfuffle
Comment[pt]='Plugin' do KArchive para o Kerfuffle
Comment[pt_BR]=Plugin KArchive para a Kerfuffle
Comment[ro]=Modul KArchive pentru Kerfuffle
Comment[ru]=Модуль KArchive для Kerfuffle
Comment[sk]=KArchive modul pre Kerfuffle
Comment[sl]=vstavek KArchive za Kerfuffle
Comment[sq]=KArchive plugin për Kerfuffle
Comment[sr]=Прикључак KArchive за Керфафл
Comment[sr@ijekavian]=Прикључак KArchive за Керфафл
Comment[sr@ijekavianlatin]=Priključak KArchive za Kerfuffle
Comment[sr@latin]=Priključak KArchive za Kerfuffle
Comment[sv]=Karchive-insticksprogram för Kerfuffle
Comment[ta]=கெர்ஃபஃபில் க்கு கேஆர்கைவ் சொருகி
Comment[th]=ส่วนเสริม Kerfuffle สำหรับใช้งานร่วมกับ KArchive
Comment[tr]=Kerfuffle için KArchive eklentisi
Comment[uk]=Додаток KArchive для Kerfuffle
Comment[x-test]=xxKArchive plugin for Kerfufflexx
Comment[zh_CN]=Kerfuffle 的 KArchive 插件
Comment[zh_TW]=Kerfuffle 的 KArchive 外掛程式
MimeType=@SUPPORTED_KARCHIVE_MIMETYPES@

==> ark-14.11.95.tar.xz: ark-14.11.95/plugins/karchiveplugin/kerfuffle_karchive.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_karchive
X-KDE-PluginInfo-Author=Henrique Pinto
X-KDE-PluginInfo-Email=henrique.pinto@kdemail.net
X-KDE-PluginInfo-Name=kerfuffle_karchive
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=117
X-KDE-Kerfuffle-APIRevision=1
Name=kerfuffle_karchive
Name[ar]=kerfuffle_karchive
Name[ast]=kerfuffle_karchive
Name[bg]=kerfuffle_karchive
Name[bs]=kerfuffle_karchive
Name[ca]=kerfuffle_karchive
Name[ca@valencia]=kerfuffle_karchive
Name[cs]=kerfuffle_karchive
Name[da]=kerfuffle_karchive
Name[de]=kerfuffle_karchive
Name[el]=kerfuffle_karchive
Name[en_GB]=kerfuffle_karchive
Name[es]=kerfuffle_karchive
Name[et]=kerfuffle_karchive
Name[eu]=kerfuffle_karchive
Name[fi]=kerfuffle_karchive
Name[fr]=kerfuffle_karchive
Name[ga]=kerfuffle_karchive
Name[gl]=kerfuffle_karchive
Name[he]=kerfuffle_karchive
Name[hne]=करफुफल_केआर्काइव
Name[hr]=kerfuffle_karchive
Name[hu]=kerfuffle_karchive
Name[ia]=kerfuffle_karchive
Name[id]=kerfuffle_karchive
Name[it]=kerfuffle_karchive
Name[ja]=kerfuffle_karchive
Name[kk]=kerfuffle_karchive
Name[km]=kerfuffle_karchive
Name[ko]=kerfuffle_karchive
Name[lt]=kerfuffle_karchive
Name[lv]=kerfuffle_karchive
Name[mr]=कर्फफल_के-संग्रह
Name[nb]=kerfuffle_karchive
Name[nds]=kerfuffle_karchive
Name[nl]=kerfuffle_karchive
Name[nn]=kerfuffle_karchive
Name[pa]=kerfuffle_karchive
Name[pl]=kerfuffle_karchive
Name[pt]=kerfuffle_karchive
Name[pt_BR]=kerfuffle_karchive
Name[ro]=kerfuffle_karchive
Name[ru]=kerfuffle_karchive
Name[sk]=kerfuffle_karchive
Name[sl]=kerfuffle_karchive
Name[sq]=kerfuffle_karchive
Name[sr]=kerfuffle_karchive
Name[sr@ijekavian]=kerfuffle_karchive
Name[sr@ijekavianlatin]=kerfuffle_karchive
Name[sr@latin]=kerfuffle_karchive
Name[sv]=Kerfuffle Karchive
Name[ta]=கெர்ஃபஃபில் கேஆர்கைவ்
Name[th]=kerfuffle_karchive
Name[tr]=kerfuffle_karchive
Name[uk]=kerfuffle_karchive
Name[wa]=kerfuffle_karchive
Name[x-test]=xxkerfuffle_karchivexx
Name[zh_CN]=kerfuffle_karchive
Name[zh_TW]=kerfuffle_karchive
Comment=KArchive plugin for Kerfuffle
Comment[ar]=KArchive ملحق لـ Kerfuffle
Comment[ast]=Aplicación KArchive pa Kerfuffle
Comment[bg]=Приставка KArchive за Kerfuffle
Comment[bs]=Priključak KArchive za Kerfafl
Comment[ca]=Connector del KArchive pel Kerfuffle
Comment[ca@valencia]=Connector del KArchive pel Kerfuffle
Comment[cs]=KArchive modul pro Kerfuffle
Comment[da]=KArchive-plugin til Kerfuffle
Comment[de]=KArchive-Modul für Kerfuffle
Comment[el]=πρόσθετο KArchive για τη Kerfuffle
Comment[en_GB]=KArchive plugin for Kerfuffle
Comment[es]=Complemento KArchive para Kerfuffle
Comment[et]=Kerfuffle'i KArchive plugin
Comment[eu]=Kerfuffle-rentzako KArchive plugina
Comment[fi]=KArchive-pakkaustuki
Comment[fr]=Module externe « KArchive » pour Kerfuffle
Comment[ga]=Breiseán KArchive le haghaidh Kerfuffle
Comment[gl]=Extensión de KArchive para Kerfuffle
Comment[he]=תוסף KArchive  עבור Kerfuffle
Comment[hne]=करफुफल बर केआर्काइव प्लगइन
Comment[hr]=Priključak KArchive za Kerfuffle
Comment[hu]=KArchive Kerfuffle-modul
Comment[ia]=Plugin de Karchive per Kerfuffle
Comment[id]=Pengaya KArchive untuk Kerfuffle
Comment[it]=Estensione KArchive per Kerfuffle
Comment[ja]=Kerfuffle のための KArchive プラグイン
Comment[kk]=Kerfuffle-ге арналған KArchive плагині
Comment[km]=កម្មវិធី​របស់ KArchive សម្រាប់ Kerfuffle
Comment[ko]=Kerfuffle을 위한 KArchive 플러그인
Comment[lt]=KArchive Kerfuffle priedas
Comment[lv]=Kerfuffle KArchive spraudnis
Comment[mr]=कर्फफल करिता के-संग्रह प्लगइन
Comment[nb]=KArchive programtillegg for Kerfuffle
Comment[nds]=KArchive-Moduul för Kerfuffle
Comment[nl]=KArchive-plug-in voor Kerfuffle
Comment[nn]=KArchive-programtillegg til Kerfuffle
Comment[pl]=Wtyczka KArchive dla Kerfuffle
Comment[pt]='Plugin' do KArchive para o Kerfuffle
Comment[pt_BR]=Plugin KArchive para a Kerfuffle
Comment[ro]=Modul KArchive pentru Kerfuffle
Comment[ru]=Модуль KArchive для Kerfuffle
Comment[sk]=KArchive modul pre Kerfuffle
Comment[sl]=Vstavek KArchive za Kerfuffle
Comment[sq]=KArchive plugin për Kerfuffle
Comment[sr]=Прикључак KArchive за Керфафл
Comment[sr@ijekavian]=Прикључак KArchive за Керфафл
Comment[sr@ijekavianlatin]=Priključak KArchive za Kerfuffle
Comment[sr@latin]=Priključak KArchive za Kerfuffle
Comment[sv]=Karchive-insticksprogram för Kerfuffle
Comment[ta]=கெர்ஃபஃபில் க்கு கேஆர்கைவ் சொருகி
Comment[th]=ส่วนเสริม Kerfuffle สำหรับใช้งานร่วมกับ KArchive
Comment[tr]=Kerfuffle için KArchive eklentisi
Comment[uk]=Додаток KArchive для Kerfuffle
Comment[x-test]=xxKArchive plugin for Kerfufflexx
Comment[zh_CN]=Kerfuffle 的 KArchive 插件
Comment[zh_TW]=Kerfuffle 的 KArchive 外掛程式
MimeType=@SUPPORTED_KARCHIVE_MIMETYPES@
